==> haskell-servant-client-0.20-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client
version:              0.20
visibility:           public
id:                   servant-client-0.20-Hl94YqxsZCc4ZfKbFHok2u
key:                  servant-client-0.20-Hl94YqxsZCc4ZfKbFHok2u
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.

    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  3f55f90b9e7c14f6360113253e906818
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.2.8/site-local/servant-client-0.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/servant-client-0.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20-Hl94YqxsZCc4ZfKbFHok2u
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    exceptions-0.10.4 http-client-0.7.15-1rEunxZVzGx9PhfeNag7Vk
    http-media-0.8.1.1-LGnUEQrIsgrLVlsSWDdr1N
    http-types-0.12.4-HcGM6QE1zVBGXemJAtRT5a
    kan-extensions-5.2.5-4LQgLLt9nJTBEl3aMxFkiN
    monad-control-1.0.3.1-3cU4uKPyCfrJqsFwwVjNlh mtl-2.2.2
    semigroupoids-5.3.7-4jaPvonLAsPBpig4bIcEIE
    servant-0.20.1-JRdWZhvOinIJ1vtpvz3lGy
    servant-client-core-0.20-ImkQPc0eHCJKbfAlYKm3JH stm-2.5.0.2
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-9OMjMe2Vj0DBq9sQ0P5ye6
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client
version:              0.20
visibility:           public
id:                   servant-client-0.20-C620Im3wBEgJ9xodOYfo7G
key:                  servant-client-0.20-C620Im3wBEgJ9xodOYfo7G
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.

    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  b3eb70f67d04d52655af5c25815db73d
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.2.8/site-local/servant-client-0.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/servant-client-0.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20-C620Im3wBEgJ9xodOYfo7G
depends:
    base-4.16.4.0 base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    bytestring-0.11.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    exceptions-0.10.4 http-client-0.7.15-BRbJDulCdHqLtoBeMVnAGg
    http-media-0.8.1.1-1UoBDThrCUL9FeZPpmgYTj
    http-types-0.12.4-ASVCDvh9rjE3eIiARG9NJE
    kan-extensions-5.2.5-Ez1HQahWVQp8yRUHXpv4fp
    monad-control-1.0.3.1-AX02qra1qxmHNghOyTYjz4 mtl-2.2.2
    semigroupoids-5.3.7-2mDe4sMNPvw975Oe5bPubt
    servant-0.20.1-DUAKjhOpLlB9B1BrR0nSil
    servant-client-core-0.20-8p6BqModzyz8h48IfRqY0x stm-2.5.0.2
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-IOayaC279jG1puxw49VnQP
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
